@@ -1,3 +1,5 @@
+import warnings
+
 from django.utils.encoding import force_unicode
 
 from selectable.base import LookupBase, ModelLookup
@@ -14,31 +16,23 @@ class LookupRegistry(object):
         if not issubclass(lookup, LookupBase):
             raise LookupInvalid(u'Registered lookups must inherit from the LookupBase class')
         if issubclass(lookup, ModelLookup) and getattr(lookup, 'search_field', None):
-            import warnings
             warnings.warn(
                 u"ModelLookup.search_field is deprecated; Use ModelLookup.search_fields instead.", 
-                DeprecationWarning
+                DeprecationWarning, stacklevel=2
             )
 
     def register(self, lookup):
-
         self.validate(lookup)
-
         name = force_unicode(lookup.name())
-
         if name in self._registry:
             raise LookupAlreadyRegistered(u'The name %s is already registered' % name)
         self._registry[name] = lookup
 
     def unregister(self, lookup):
-
         self.validate(lookup)
-    
         name = force_unicode(lookup.name())
-
         if name not in self._registry:
            raise LookupNotRegistered(u'The name %s is not registered' % name)
-    
         del self._registry[name]
 
     def get(self, key):
@@ -63,7 +57,5 @@ def autodiscover():
             import_module('%s.lookups' % app)
         except:
             registry._registry = before_import_registry
-
             if module_has_submodule(mod, 'lookups'):
                 raise
-
